summaryrefslogtreecommitdiffstats
path: root/src/core/hle/kernel/k_process.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/hle/kernel/k_process.h')
-rw-r--r--src/core/hle/kernel/k_process.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/hle/kernel/k_process.h b/src/core/hle/kernel/k_process.h
index 76ece119f..8a8c1fcbb 100644
--- a/src/core/hle/kernel/k_process.h
+++ b/src/core/hle/kernel/k_process.h
@@ -154,8 +154,8 @@ public:
return process_id;
}
- /// Gets the title ID corresponding to this process.
- u64 GetTitleID() const {
+ /// Gets the program ID corresponding to this process.
+ u64 GetProgramID() const {
return program_id;
}